{% if pagename != 'search' %}
<div class="block">
  <h3 class="subtitle">{{ _('Quick search') }}</h3>
  <form method="get" action="{{ pathto('search') }}" role="search">
    <div class="field has-addons">
      <div class="control">
        <input class="input" type="text" placeholder="{{ _('Search') }}" name="q" aria-label="{{ _('Search') }}">
      </div>
      <div class="control">
        <button class="button is-info">
          {{ _('Search') }}
        </button>
      </div>
    </div>
  </form>
</div>
{% endif %}
