{%- if show_source and has_source and sourcename %}
  <div class="block" id="sidebar-toc">
    <h3 class="subtitle">{{ _('This Page') }}</h3>
    <aside class="menu">
      <ul class="menu-list">
        <li><a href="{{ pathto('_sources/' + sourcename, true)|e }}"
            rel="nofollow">{{ _('Show Source') }}</a></li>
      </ul>
    </aside>
  </div>
{% endif %}
