{% if display_toc %}
  <div class="block" id="sidebar-toc">
    <h3 class="subtitle">{{ _('Table of Contents') }}</h3>
    <aside class="menu">
      {{ toc }}
    </aside>
  </div>
  {# TODO: Must regenerate ``doc`` in build proc. #}
  <script>
    document.querySelector("#sidebar-toc ul").classList.add("menu-list")
  </script>
{% endif %}
